@@ -1,4 +1,5 @@
 import argparse
+import sys
 
 from faker import Faker
 
@@ -31,9 +32,14 @@ def setup_argparse():
 
 
 def main():
-    parser = setup_argparse()
-    args = parser.parse_args()
-    process_args(args)
+    try:
+        parser = setup_argparse()
+        args = parser.parse_args()
+        process_args(args)
+        sys.exit()
+    except Exception as ex:
+        print(ex)
+        sys.exit(1)
 
 
 if __name__ == "__main__":
